as_abundances.Rdas_abundances returns a tidy data frame given a numerical abundance
matrix.
as_abundances(abundances_matrix, taxa_are_columns = TRUE, value = "abundance")The ambundance matrix that will be converted.
A logical scalar. Are the taxa defined in columns? Default is TRUE.
Name of resulting colum containing the abundance data. Default is "abundance".
This function will convert a numerical abundance matrix into a tidy data
frame. To convert a tidy data frame into a numerical abundance matrix
use as_abundances_matrix.