create_tidyamplicons.Rdtidyamplicons returns a tidyamplicons object given a numeric matrix.
create_tidyamplicons(abundance_matrix, taxa_are_columns = TRUE)Numerical matrix containing the abundance data.
A logical scalar. Are the taxa defined in columns?
This function initiates a tidyamplicons object based on a numeric matrix. It
will automatically create a dummy taxa and sample table which will need to be
updated using the functions add_taxon_tibble and
add_sample_tibble.