occurrences.RdReturns a tidy table of occurrences: taxon presence counts in samples, overall or per condition.
occurrences(ta, condition = NULL, pres_abs = F)a tidyamplicons object
a string denoting a categorical variable in the sample table
wether to resort to presence/absense screening
Condition should be a categorical variable present in the samples table. Supply condition as a string.