This function executes the adonis function of the vegan package and returns the result.

perform_adonis(ta, predictors, permutations = 999)

Arguments

ta

A tidyamplicons object.

predictors

A character vector with predictors to include in the model.

permutations

The number of permutations (more permutations takes longer but gives a more accurate p-value).

Value

An object of class "adonis" (see adonis).

Details

Samples where one or more predictors are NA are removed.