perform_adonis.RdThis function executes the adonis function of the vegan package and returns the result.
perform_adonis(ta, predictors, permutations = 999)A tidyamplicons object.
A character vector with predictors to include in the model.
The number of permutations (more permutations takes longer but gives a more accurate p-value).
An object of class "adonis" (see adonis).
Samples where one or more predictors are NA are removed.